@@ -13,7 +13,7 @@ SERVICES = (
 class Config(models.Model):
     service = models.CharField(max_length=50, choices=SERVICES, null=False)
     key = models.CharField(max_length=50, null=False, unique=True)
-    value = models.CharField(max_length=100, null=False)
+    value = models.TextField(null=False)
     date_created = models.DateTimeField(auto_now_add=True)
     date_updated = models.DateTimeField(auto_now=True)
     last_updated_by = models.ForeignKey(User, models.SET_NULL,
